from typing import Optional, List

from pydantic import BaseModel, Field


class Llm(BaseModel):
    id: str = Field(description="ID")
    nickname: Optional[str] = Field(description="llm nickname", default="")
    temperature: Optional[float] = Field(description="llm temperature", default=None)
    model_name: Optional[List[str]] = Field(description="llm model name list", default=[])



from typing import List
from fastapi import APIRouter, HTTPException
from agentuniverse_product.service.llm_service.llm_service import LLMService
from agentuniverse_product.service.model.llm_dto import LlmDTO

router = APIRouter()
llms_router = router


@router.get("/llms", response_model=List[LlmDTO])
async def get_agents():
    return LLMService.get_llm_list()
